# FRITTer

Frame
Rate
Independent
Timer
Tree
Emulating
Real-time

Sometimes you want to move an object in a simulation or progress an animation.

One day, this might be a library that lets you do that!
